@@ -1,10 +1,7 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
-    "Storage invalid" : "A tároló érvénytelen",
-    "Unknown error" : "Ismeretlen hiba",
-    "File could not be found" : "Fájl nem található",
+    "File could not be found" : "A fájl nem található",
     "Move or copy" : "Áthelyezés vagy másolás",
     "Download" : "Letöltés",
     "Delete" : "Törlés",
@@ -13,7 +10,6 @@ OC.L10N.register(
     "Show grid view" : "Rácsnézet megjelenítése",
     "Home" : "Saját mappa",
     "Close" : "Bezárás",
-    "Favorites" : "Kedvencek",
     "Could not create folder \"{dir}\"" : "A(z) „{dir}” mappa nem hozható létre",
     "This will stop your current uploads." : "Ez meg fogja állítani a jelenlegi feltöltéseket.",
     "Upload cancelled." : "Feltöltés megszakítva.",
@@ -26,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Ismeretlen hiba történt",
     "File could not be uploaded" : "A fájlt nem lehetett feltölteni",
     "Uploading …" : "Feltöltés…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Feltöltés… ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Ezen elem feltöltése nem támogatott",
     "Target folder does not exist any more" : "A célmappa már nem létezik",
@@ -36,8 +34,10 @@ OC.L10N.register(
     "Move" : "Áthelyezés",
     "Copy" : "Másolás",
     "Choose target folder" : "Válasszon célmappát",
+    "Set reminder" : "Emlékeztető beállítása",
+    "Edit locally" : "Szerkesztés helyileg",
     "Open" : "Megnyitás",
-    "Delete file" : "Fájl törlése",
+    "Delete file" : "Fájlok törlése",
     "Delete folder" : "Mappa törlése",
     "Disconnect storage" : "Tároló leválasztása",
     "Leave this share" : "Megosztás elhagyása",
@@ -52,6 +52,7 @@ OC.L10N.register(
     "Unable to determine date" : "Nem lehet meghatározni a dátumot",
     "This operation is forbidden" : "Ez a művelet tiltott",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem érhető el, nézze meg a naplófájlokat vagy lépjen kapcsolatba az adminisztrátorral",
+    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
     "Could not move \"{file}\", target exists" : "A(z) „{file}” nem helyezhető át, mert a cél már létezik",
     "Could not move \"{file}\"" : "A(z) „{file}” nem helyezhető át",
     "copy" : "másolat",
@@ -59,6 +60,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "A(z) „{file}” másolása sikertelen",
     "Copied {origin} inside {destination}" : "A(z) {origin} átmásolva ide: {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "A(z) {origin} és {nbfiles} egyéb fájl átmásolva ide: {destination}",
+    "Failed to redirect to client" : "Nem sikerült az átirányítás a klienshez",
     "{newName} already exists" : "A(z) {newName} már létezik",
     "Could not rename \"{fileName}\", it does not exist any more" : "A(z) „{fileName}” átnevetése sikertelen, mert már nem létezik",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "A(z) „{targetName}” név már használatban van a(z) „{dir}” mappában. Válasszon másik nevet.",
@@ -79,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["köztük %n rejtett","köztük %n rejtett"],
     "You do not have permission to upload or create files here" : "Nincs jogosultsága fájlok ide feltöltéséhez vagy létrehozásához",
     "_Uploading %n file_::_Uploading %n files_" : ["%n fájl feltöltése","%n fájl feltöltése"],
+    "New" : "Új",
     "New file/folder menu" : "Új fájl/mappa menü",
     "Select file range" : "Válasszon fájltartományt",
     "{used}%" : "{used}%",
@@ -98,14 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Tárhelye majdnem megtelt ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["megfelel ennek: „{filter}”","megfelel ennek: „{filter}”"],
     "View in folder" : "Megtekintés mappában",
-    "Copied!" : "Másolva!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Közvetlen hivatkozás másolása (csak azoknál a felhasználóknál működik, akiknek hozzáférése van a fájlhoz/mappához)",
     "Path" : "Útvonal",
     "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
     "Favorited" : "Kedvenc",
     "Favorite" : "Kedvenc",
-    "You can only favorite a single file or folder at a time" : "Egyszerre csak egy fájlt vagy mappát jelölhet meg kedvencként",
     "New folder" : "Új mappa",
+    "Create new folder" : "Új mappa létrehozása",
     "Upload file" : "Fájl feltöltése",
     "Recent" : "Legutóbbi",
     "Not favorited" : "Nincs a kedvencek között",
@@ -116,6 +117,7 @@ OC.L10N.register(
     "Removed from favorites" : "Eltávolítva a kedvencekből",
     "You added {file} to your favorites" : "Hozzáadta a kedvencekhez: {file}",
     "You removed {file} from your favorites" : "Eltávolította a kedvencek közül: {file}",
+    "Favorites" : "Kedvencek",
     "File changes" : "Fájlváltozások",
     "Created by {user}" : "Létrehozta: {user}",
     "Changed by {user}" : "Módosította: {user}",
@@ -123,7 +125,6 @@ OC.L10N.register(
     "Restored by {user}" : "Helyreállította: {user}",
     "Renamed by {user}" : "Átnevezte: {user}",
     "Moved by {user}" : "Áthelyezte: {user}",
-    "\"remote user\"" : "„távoli felhasználó”",
     "You created {file}" : "Létrehozta: {file}",
     "You created an encrypted file in {file}" : "Létrehozott egy titkosított fájlt ebben: {file}",
     "{user} created {file}" : "{user} létrehozta: {file}",
@@ -152,8 +153,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Egy fájl eltávolítva vagy hozzáadva a <strong>kedvencekhez</strong>",
     "A file or folder has been <strong>changed</strong>" : "Egy fájl vagy mappa <strong>megváltozott</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Egy kedvenc fájl vagy mappa <strong> megváltozott</strong>",
-    "All files" : "Az összes fájl",
-    "Unlimited" : "Korlátlan",
     "Upload (max. %s)" : "Feltöltés (legfeljebb %s)",
     "Accept" : "Elfogadás",
     "Reject" : "Elutasítás",
@@ -167,61 +166,154 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "A(z) {path} tulajdonjogának átruházása {user} részéről sikeres.",
     "in %s" : "itt:  %s",
     "File Management" : "Fájlkezelés",
+    "Reload current directory" : "Jelenlegi könyvtár újratöltése",
+    "Go to the \"{dir}\" directory" : "Ugrás a(z) „{dir}” könyvtárhoz",
+    "Drag and drop files here to upload" : "Húzza ide a fájlokat a feltöltéshez",
+    "Your have used your space quota and cannot upload files anymore" : "Már felhasználta a tárhelykvótáját, így már nem tölthet fel fájlokat",
+    "You don’t have permission to upload or create files here" : "Nincs jogosultsága ahhoz, hogy fájlokat ide töltsön fel vagy hozzon létre",
+    "\"{displayName}\" action executed successfully" : "A(z) „{displayName}” művelet sikeresen végrehajtva",
+    "\"{displayName}\" action failed" : "A(z) „{displayName}” művelet sikertelen",
+    "Rename file" : "Fájl átnevezése",
+    "File name" : "Fájlnév",
+    "Folder name" : "Mappanév",
+    "This node is unavailable" : "Ez az elem nem érhető el",
+    "Download file {name}" : "A(z) {name} fájl letöltése",
+    "\"{name}\" is not an allowed filetype." : "A(z) „{name}” nem engedélyezett fájltípus.",
+    "{newName} already exists." : "A(z) {newName} már létezik.",
+    "\"{char}\" is not allowed inside a file name." : "„{char}” nem szerepelhet fájlnévben.",
+    "Name cannot be empty" : "A név nem lehet üres",
+    "Another entry with the same name already exists" : "Már létezik ilyen nevű bejegyzés",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "A(z) „{oldName}” átnevezve erre: „{newName}”",
+    "Could not rename \"{oldName}\", it does not exist any more" : "A(z) „{fileName}” nem nevezhető át, mert már nem létezik",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "A(z) „{newName}” név már használatban van a(z) „{dir}” mappában. Válasszon másik nevet.",
+    "Could not rename \"{oldName}\"" : "A(z) „{oldName}” nem nevezhető át",
+    "Total rows summary" : "Összes sor összegzése",
+    "\"{displayName}\" failed on some elements " : "A(z) „{displayName}” sikertelen volt néhány elemen",
+    "\"{displayName}\" batch action executed successfully" : "A(z) „{displayName}” tömeges művelet sikeresen végrehajtva",
+    "List of files and folders." : "Fájlok és mappák felsorolása.",
+    "Column headers with buttons are sortable." : "A gombot tartalmazó oszlopfejlécek rendezhetők.",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ez a lista teljesítménybeli okokból nincs teljes egészében megjelenítve. A fájlok a listában navigálás során jelennek meg.",
+    "File not found" : "A fájl nem található",
+    "Storage informations" : "Tárhely-információk",
+    "{usedQuotaByte} used" : "{usedQuotaByte} felhasználva",
+    "{relative}% used" : "{relative}% felhasználva",
+    "Could not refresh storage stats" : "Nem sikerült frissíteni a tárhelystatisztikákat",
+    "Your storage is full, files can not be updated or synced anymore!" : "A tárhelye megtelt, a fájlok többé nem frissíthetők vagy szinkronizálhatók.",
+    "Create" : "Létrehozás",
     "Transfer ownership of a file or folder" : "Fájl vagy mappa tulajdonjogának átruházása",
     "Choose file or folder to transfer" : "Válasszon egy fájlt vagy mappát az átruházáshoz",
     "Change" : "Módosítás",
     "New owner" : "Új tulajdonos",
-    "Search users" : "Fehasználók keresése",
     "Choose a file or folder to transfer" : "Válassz egy átruházandó fájlt vagy mappát",
     "Transfer" : "Átruházás",
     "Transfer {path} to {userid}" : "{path} átruházása {userid} számára",
     "Invalid path selected" : "Érvénytelen útvonal kiválasztva",
+    "Unknown error" : "Ismeretlen hiba",
     "Ownership transfer request sent" : "Tulajdonjog átruházási kérés elküldve",
     "Cannot transfer ownership of a file or folder you do not own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
+    "Select file or folder to link to" : "Válassza ki a hivatkozandó fájlt vagy mappát",
+    "Choose file" : "Válasszon fájlt",
+    "Choose {file}" : "{file} kiválasztása",
+    "Loading current folder" : "Jelenlegi mappa betöltése",
+    "No files in here" : "Itt nincsenek fájlok",
+    "Upload some content or sync with your devices!" : "Töltsön fel néhány tartalmat, vagy szinkronizáljon az eszközeivel.",
+    "Go to the previous folder" : "Ugrás az előző mappához",
+    "Go back" : "Visszalépés",
+    "Share" : "Megosztás",
+    "Shared by link" : "Megosztva hivatkozással",
+    "Shared" : "Megosztva",
+    "Switch to list view" : "Váltás listanézetre",
+    "Switch to grid view" : "Váltás rácsnézetre",
+    "Error during upload: {message}" : "Hiba a feltöltés során: {message}",
+    "Unknown error during upload" : "Ismeretlen hiba a feltöltés során",
+    "Open the files app settings" : "Nyissa meg a Fájlok lalkalmazás beállításait",
+    "Files settings" : "Fájlok beállításai",
+    "File cannot be accessed" : "A fájl nem érhető el",
+    "Open in files" : "Megnyitás a Files-ban",
+    "Sort favorites first" : "Kedvencek előre rendezése",
+    "Show hidden files" : "Rejtett fájlok megjelenítése",
+    "Crop image previews" : "Kép előnézetek vágása",
+    "Enable the grid view" : "Rácsnézet engedélyezése",
+    "Additional settings" : "További beállítások",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV-webcím",
+    "Copy to clipboard" : "Másolás a vágólapra",
+    "Use this address to access your Files via WebDAV" : "Ezzel a címmel férhet hozzá a Fájlokhoz a WebDAV-on keresztül",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ha engedélyezte a kétfaktoros hitelesítést, akkor kattintson ide, hogy létrehozzon egy új alkalmazásjelszót, és azt használja.",
+    "Clipboard is not available" : "A vágólap nem érhető el",
+    "WebDAV URL copied to clipboard" : "A WebDAV-cím a vágólapra másolva",
     "Unable to change the favourite state of the file" : "Nem lehet megváltoztatni a fájl kedvenc állapotát",
     "Error while loading the file data" : "Hiba történt a fájladatok betöltése közben",
     "Pick a template for {name}" : "Válassz sablont a(z) {name} fájlnak",
-    "Cancel" : "Mégse",
-    "Create" : "Létrehozás",
     "Create a new file with the selected template" : "Új fájl létrehozása a kiválasztott sablonnal",
     "Creating file" : "Fájl létrehozása",
     "Blank" : "Üres",
     "Unable to create new file from template" : "Nem lehet új fájlt létrehozni a sablonból",
-    "Set up templates folder" : "Személyes sablonmappa beállítása",
-    "Templates" : "Sablonok",
+    "Delete permanently" : "Végleges törlés",
+    "Delete files" : "Fájlok törlése",
+    "Cancel" : "Mégse",
+    "Destination is not a folder" : "A cél nem mappa",
+    "This file/folder is already in that directory" : "Ez a fájl/mappa már létezik a mappában",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "A fájl/mappa önmagába, vagy saját almappájába áthelyezése nem lehetséges",
+    "A file or folder with that name already exists in this folder" : "Már létezik ilyen nevű fájl vagy mappa ebben a mappában",
+    "The file does not exist anymore" : "Ez a fájl már nem létezik",
+    "Copy to {target}" : "Másolás ide: {target}",
+    "Move to {target}" : "Áthelyezés ide: {target}",
+    "Cancelled move or copy operation" : "Az áthelyezés vagy másolás művelet megszakítva",
+    "Open folder {displayName}" : "A(z) {displayName} mappa megnyitása",
+    "Open in Files" : "Megnyitás a Fájlokban",
+    "Open details" : "Részletek megnyitása",
+    "Created new folder \"{name}\"" : "Új „{name}” mappa létrehozva",
+    "Filename" : "Fájlnév",
     "Unable to initialize the templates directory" : "A sablonkönyvtár előkészítése sikertelen",
-    "%s used" : "%s használt",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s / %2$s felhasználva",
-    "Files settings" : "Fájlok beállításai",
-    "Show hidden files" : "Rejtett fájlok megjelenítése",
-    "Crop image previews" : "Kép előnézetek vágása",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Ezzel a címmel férhet hozzá a Fájlokhoz a WebDAV-on keresztül",
-    "Toggle %1$s sublist" : "%1$s allista be/ki",
-    "Toggle grid view" : "Rácsnézet be/ki",
-    "No files in here" : "Itt nincsenek fájlok",
-    "Upload some content or sync with your devices!" : "Töltsön fel néhány tartalmat, vagy szinkronizáljon az eszközeivel.",
+    "Create new templates folder" : "Új sablonmappa létrehozása",
+    "Templates" : "Sablonok",
+    "One of the dropped files could not be processed" : "Egy vagy több idehúzott fájl nem dolgozható fel",
+    "Some files could not be moved" : "Néhány fájl nem helyezhető át",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappa","{folderCount} mappa"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fájl","{fileCount} fájl"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fájl és {folderCount} mappa","1 fájl és {folderCount} mappa"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fájl és 1 mappa","{fileCount} fájl és 1 mappa"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} fájl és {folderCount} mappa",
+    "List of favorites files and folders." : "Kedvenc fájlok és mappák felsorolása.",
+    "No favorites yet" : "Még nincsenek kedvencek",
+    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találja meg",
+    "All files" : "Az összes fájl",
+    "List of your files and folders." : "Saját fájlok és mappák felsorolása.",
+    "List of recently modified files and folders." : "Közelmúltban módosított fájlok és mappák felsorolása.",
+    "No recently modified files" : "Nincs a közelmúltban módosított fájl",
+    "Files and folders you recently modified will show up here." : "Az Ön által módosított fájlok és mappák itt jelennek meg.",
     "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
     "Select all" : "Összes kijelölése",
     "Upload too large" : "A feltöltés túl nagy",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltölteni próbált fájlok mérete meghaladja a kiszolgálón megengedett legnagyobb méretet.",
-    "No favorites yet" : "Még nincsenek kedvencek",
-    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találja meg",
-    "Deleted files" : "Törölt fájlok",
+    "Text file" : "Szövegfájl",
+    "New text file.txt" : "Új szövegfájl.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "A közvetlen hivatkozás másolva (csak azon felhasználóknak működik, akik elérik ezt a fájlt/mappát)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Közvetlen hivatkozás másolása (csak azoknál a felhasználóknál működik, akiknek hozzáférése van a fájlhoz/mappához)",
+    "You can only favorite a single file or folder at a time" : "Egyszerre csak egy fájlt vagy mappát jelölhet meg kedvencként",
+    "This file has the tag {tag}" : "Ennek a fájlnak ez a címkéje: {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Ennek a fájlnak ezek a címkéi: {firstTags} és {lastTag}",
+    "\"remote user\"" : "„távoli felhasználó”",
+    "Select the row for {displayName}" : "A(z) {displayName} sorának kiválasztása",
+    "Open folder {name}" : "A(z) {name} mappa megnyitása",
+    "Unselect all" : "Kijelölés megszüntetése",
+    "ascending" : "növekvő",
+    "descending" : "csökkenő",
+    "Sort list by {column} ({direction})" : "Lista rendezése {column} alapján ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ez a lista teljesítménybeli okokból nincs teljes egészében megjelenítve. A fájlok a listában navigálás során jelennek meg, ",
+    "Search for an account" : "Fiók keresése",
+    "Choose" : "Válasszon",
+    "No files or folders have been deleted yet" : "Még nem lettek fájlok vagy mappák törölve",
+    "You might not have have permissions to view it, ask the sender to share it" : "Lehet, hogy nincs jogosultsága, hogy megtekintse, kérje meg a küldőt, hogy ossza meg",
+    "Set up templates folder" : "Személyes sablonmappa beállítása",
+    "Toggle %1$s sublist" : "%1$s allista be/ki",
+    "Toggle grid view" : "Rácsnézet be/ki",
     "Shares" : "Megosztások",
     "Shared with others" : "Megosztva másokkal",
     "Shared with you" : "Megosztva Önnel",
-    "Shared by link" : "Megosztva hivatkozással",
     "Deleted shares" : "Törölt megosztások",
     "Pending shares" : "Függőben lévő megosztások",
-    "Text file" : "Szövegfájl",
-    "New text file.txt" : "Új szövegfájl.txt",
-    "Select" : "Kiválasztás",
-    "You don’t have permission to upload or create files here" : "Nincs jogosultsága fájlok ide feltöltéséhez vagy létrehozásához",
-    "New" : "Új",
-    "Cannot transfer ownership of a file or folder you don't own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
-    "%s%% of %s used" : "%s %% / %s felhasználva",
-    "Settings" : "Beállítások"
+    "The files is locked" : "Ez a fájl zárolva van"
 },
 "nplurals=2; plural=(n != 1);");
