@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Public link" : "Esteka publikoa",
     "Photos" : "Argazkiak",
+    "On This Day" : "Egun honetan",
     "Your memories under your control" : "Zure oroitzapenak zure kontrolpean",
     "All media" : "Fitxategi guztiak",
     "Videos" : "Bideoak",
@@ -48,6 +49,9 @@ OC.L10N.register(
     "Failed to update album." : "Ezin izan da albuma eguneratu.",
     "This collection does not exist" : "Bilduma hau ez da existitzen",
     "An error occurred" : "Errore bat gertatu da",
+    "No picture for this day" : "Ez dago argazkirik egun honentzat",
+    "Picture taken on this day will show up here." : "Egun honetan hartutako argazkia hemen agertuko da.",
+    "More photos from this day" : "Egun honetako argazki gehiago",
     "_%n unassigned photo_::_%n unassigned photos_" : ["Esleitu gabeko argazki %n","%n esleitu gabeko argazki"],
     "Favorite" : "Egin gogoko",
     "Select image {imageName}" : "Hautatu irudia {imageName}",
@@ -66,6 +70,7 @@ OC.L10N.register(
     "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
     "Delete source directory" : "Ezabatu iturburuko direktorioa",
     "All folders" : "Karpeta guztiak",
+    "Add a Photos source for the timelines" : "Gehitu argazki iturri bat denbora-lerroetarako",
     "Add folder" : "Gehitu karpeta",
     "Select a source folder for your media" : "Hautatu iturburu karpeta bat zure multimedia fitxategientzat",
     "Home" : "Etxea",
@@ -73,6 +78,7 @@ OC.L10N.register(
     "Choose a different folder" : "Aukeratu beste karpeta bat",
     "Select the default upload location for your media" : "Hautatu lehenetsitako kokalekua zure multimedia fitxategiak igotzeko",
     "View" : "Ikusi",
+    "Media folders" : "Multimedia karpetak",
     "Choose the folders from where photos and videos are shown." : "Aukeratu zein karpetatatik erakutsiko diren argazki eta bideoak.",
     "Upload folder" : "Igo karpeta",
     "Choose the folder where photos and albums are uploaded to." : "Aukeratu zein karpetatara igoko diren argazki eta albumak.",
@@ -120,6 +126,7 @@ OC.L10N.register(
     "No tags yet" : "Etitketarik ez oraindik",
     "Photos with tags will show up here" : "Etiketadun argazkiak hemen erakutsiko dira",
     "Popular tags" : "Etiketa ohikoak",
+    "One of the source folders does not exists" : "Iturburu-karpeta bat ez da existitzen",
     "Add" : "Gehitu",
     "Add to album" : "Gehitu albumera",
     "Delete selection" : "Ezabatu hautatutakoak",
@@ -167,8 +174,6 @@ OC.L10N.register(
     "Create a new album" : "Sortu album berri bat",
     "Add selection to an album" : "Gehitu hautatutakoak album batera",
     "Failed to create {albumName}." : "Ezin izan da {albumName} sortu.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Ezin izan da {currentAlbumName} berrizendatu {newAlbumName} gisa.",
-    "Media folder" : "Multimedia karpeta",
-    "The source folder does not exists" : "Iturburuko karpeta ez da existitzen"
+    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Ezin izan da {currentAlbumName} berrizendatu {newAlbumName} gisa."
 },
 "nplurals=2; plural=(n != 1);");
