@@ -93,13 +93,14 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan inte installeras eftersom den inte är kompatibel med den här versionen av servern.",
     "__language_name__" : "Svenska",
     "This is an automatically sent email, please do not reply." : "Detta är ett automatiskt e-postmeddelande, du kan därmed inte svara på det.",
+    "Help & privacy" : "Hjälp & integritet",
     "Appearance and accessibility" : "Utseende och tillgänglighet",
     "Apps" : "Appar",
     "Personal settings" : "Personlig information",
     "Administration settings" : "Administration",
     "Settings" : "Inställningar",
     "Log out" : "Logga ut",
-    "Users" : "Användare",
+    "Accounts" : "Konton",
     "Email" : "E-post",
     "Mail %s" : "Skicka e-post %s",
     "Fediverse" : "Fediverse",
@@ -261,17 +262,20 @@ OC.L10N.register(
     "Storage connection error. %s" : "Lagringsutrymme lyckas inte ansluta. %s",
     "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
     "Storage connection timeout. %s" : "Lagringsutrymme lyckas inte ansluta \"timeout\". %s",
-    "Generate headline" : "Skapa rubrik",
+    "Prompt" : "Uppmaning",
     "Generates a possible headline for a text." : "Genererar en möjlig rubrik för en text.",
     "Summarize" : "Sammanfatta",
-    "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
+    "Summary" : "Sammanfattning",
     "Extract topics" : "Extrahera ämnen",
+    "Generate headline" : "Skapa rubrik",
+    "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken.",
     "404" : "404",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Inloggad användare måste vara en admin, sub-admin eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
     "Logged in user must be an admin or sub admin" : "Inloggad användare måste vara administratör eller del-administratör",
     "Logged in user must be an admin" : "Inloggad användare måste vara administratör",
     "Help" : "Hjälp",
+    "Users" : "Användare",
     "Unknown user" : "Okänd användare",
     "Enter the database username and name for %s" : "Ange databasanvändarnamn och lösenord för %s",
     "Enter the database username for %s" : "Ange databasanvändare för %s",
